changeset 111867:930d5c8afda2

arc-mode.el (archive-zip-extract): If w32-quote-process-args is nil, do quote archive member names. Suggested by hm <helmut.muelner@joanneum.at>.
author Eli Zaretskii <eliz@gnu.org>
date Fri, 10 Dec 2010 13:56:44 +0200
parents dc4c9e6071a2
children 98f94116b751
files lisp/ChangeLog lisp/arc-mode.el
diffstat 2 files changed, 10 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Thu Dec 09 19:47:49 2010 -0800
+++ b/lisp/ChangeLog	Fri Dec 10 13:56:44 2010 +0200
@@ -1,3 +1,8 @@
+2010-12-10  Eli Zaretskii  <eliz@gnu.org>
+
+	* arc-mode.el (archive-zip-extract): If w32-quote-process-args is
+	nil, do quote archive member names.  (Bug#6144)
+
 2010-12-10  Glenn Morris  <rgm@gnu.org>
 
 	* files.el (diff-no-select): Declare.
--- a/lisp/arc-mode.el	Thu Dec 09 19:47:49 2010 -0800
+++ b/lisp/arc-mode.el	Fri Dec 10 13:56:44 2010 +0200
@@ -1813,10 +1813,12 @@
      archive
      ;; unzip expands wildcards in NAME, so we need to quote it.  But
      ;; not on DOS/Windows, since that fails extraction on those
      ;; systems, and file names with wildcards in zip archives don't
      ;; work there anyway.
      ;; FIXME: Does pkunzip need similar treatment?
-     (if (and (not (memq system-type '(windows-nt ms-dos)))
+     (if (and (or (not (memq system-type '(windows-nt ms-dos)))
+		  (and (boundp 'w32-quote-process-args)
+		       (null w32-quote-process-args)))
 	      (equal (car archive-zip-extract) "unzip"))
 	 (shell-quote-argument name)
        name)
@@ -1813,10 +1813,12 @@
      ;; unzip expands wildcards in NAME, so we need to quote it.  But
      ;; not on DOS/Windows, since that fails extraction on those
-     ;; systems, and file names with wildcards in zip archives don't
-     ;; work there anyway.
+     ;; systems (unless w32-quote-process-args is nil), and file names
+     ;; with wildcards in zip archives don't work there anyway.
      ;; FIXME: Does pkunzip need similar treatment?